/*
    Contact Form Template
    Copyright (C) 2024

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY. See the GNU General Public License for more details.
*/

class CaptchaManager {
    constructor() {
        this.num1 = document.getElementById('num1');
        this.num2 = document.getElementById('num2');
        this.operator = document.getElementById('operator');
        this.refreshBtn = document.getElementById('refreshCaptcha');
        this.form = document.getElementById('contactForm');
        
        this.operators = ['+', '-', '×'];
        this.expectedResult = 0;
        
        this.initializeEventListeners();
        this.generateCaptcha();
    }

    initializeEventListeners() {
        this.refreshBtn.addEventListener('click', () => this.generateCaptcha());
        this.form.addEventListener('submit', (e) => this.validateForm(e));
    }

    generateCaptcha() {
        const number1 = Math.floor(Math.random() * 10) + 1;
        const number2 = Math.floor(Math.random() * 10) + 1;
        const selectedOperator = this.operators[Math.floor(Math.random() * this.operators.length)];

        this.num1.textContent = number1;
        this.num2.textContent = number2;
        this.operator.textContent = selectedOperator;

        switch(selectedOperator) {
            case '+':
                this.expectedResult = number1 + number2;
                break;
            case '-':
                this.expectedResult = number1 - number2;
                break;
            case '×':
                this.expectedResult = number1 * number2;
                break;
        }

        document.getElementById('captchaResult').value = '';
    }

    validateForm(e) {
        e.preventDefault();
        
        const userResult = parseInt(document.getElementById('captchaResult').value);
        
        if (userResult === this.expectedResult) {
            this.form.submit();
        } else {
            alert('CAPTCHA incorrect. Veuillez réessayer.');
            this.generateCaptcha();
        }
    }
}

// Initialisation
document.addEventListener('DOMContentLoaded', () => {
    new CaptchaManager();
});
